'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useDebouncedCallback;

var _require = require('react'),
    useRef = _require.useRef,
    useCallback = _require.useCallback,
    useEffect = _require.useEffect;

function useDebouncedCallback(callback, delay) {
  var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  var maxWait = options.maxWait;
  var maxWaitHandler = useRef(null);
  var maxWaitArgs = useRef([]);
  var functionTimeoutHandler = useRef(null);
  var isComponentUnmounted = useRef(false);

  var debouncedFunction = callback;

  var cancelDebouncedCallback = useCallback(function () {
    clearTimeout(functionTimeoutHandler.current);
    clearTimeout(maxWaitHandler.current);
    maxWaitHandler.current = null;
    maxWaitArgs.current = [];
    functionTimeoutHandler.current = null;
  }, [functionTimeoutHandler.current, maxWaitHandler.current]);

  useEffect(function () {
    return function () {
      // we use flag, as we allow to call callPending outside the hook
      isComponentUnmounted.current = true;
    };
  }, []);

  var debouncedCallback = useCallback(function () {
    var _arguments = arguments;

    maxWaitArgs.current = arguments;
    clearTimeout(functionTimeoutHandler.current);
    functionTimeoutHandler.current = setTimeout(function () {
      if (!isComponentUnmounted.current) {
        debouncedFunction.apply(null, _arguments);
      }

      cancelDebouncedCallback();
    }, delay);

    if (maxWait && !maxWaitHandler.current) {
      maxWaitHandler.current = setTimeout(function () {
        if (!isComponentUnmounted.current) {
          debouncedFunction.apply(null, maxWaitArgs.current);
        }
        cancelDebouncedCallback();
      }, maxWait);
    }
  }, [debouncedFunction, maxWait, delay]);

  var callPending = function callPending() {
    // Call pending callback only if we have anything in our queue
    if (!functionTimeoutHandler.current) {
      return;
    }

    debouncedFunction.apply(null, maxWaitArgs.current);
    cancelDebouncedCallback();
  };

  // At the moment, we use 3 args array so that we save backward compatibility
  return [debouncedCallback, cancelDebouncedCallback, callPending];
}